==> create-ev0-app-0.2.1.tgz: package/README.md <==
# EV0 App

The best way to start your next Next.js project in a type-safe environment. Get started with the EV0 Stack by running `npx create-ev0-app@latest init`

## Getting Started

To get started with the EV0 Stack, you can run the following command:

```bash
npx create-ev0-app@latest init
# or
yarn create-ev0-app@latest init
# or
pnpm dlx create-ev0-app@latest init
# or
bunx create-ev0-app@latest init
```

## The EV0 Stack

The EV0 Stack is a full-stack TypeScript framework that helps you build fast, robust, and maintainable web applications using the latest technologies. It is built on top of the following technologies:

-   **[Next.js](https://nextjs.org/)**: A React framework that enables server-side rendering and static site generation.
-   **[TypeScript](https://www.typescriptlang.org/)**: A superset of JavaScript that adds static types to the language.
-   **[Tailwind CSS](https://tailwindcss.com/)**: A utility-first CSS framework for rapidly building custom designs.
-   **[ShadCN UI](https://ui.shadcn.com/)**: A collection of accessible, reusable, and customizable UI components.
-   **[tRPC](https://trpc.io/)**: A TypeScript-first framework for building scalable and type-safe APIs.
-   **[Supabase](https://supabase.io/)**: An open-source alternative to Firebase that provides a real-time database and authentication system.
-   **[Clerk](https://clerk.com/)**: A user authentication and authorization service that provides a secure and customizable login experience.
-   **[MongoDB (Coming Soon)](https://www.mongodb.com/)**: A NoSQL database that provides a flexible and scalable data storage solution.
-   **[Drizzle](https://orm.drizzle.team/)**: A TypeScript-first ORM that provides a type-safe and efficient way to interact with databases.
-   **[Prisma (Coming Soon)](https://www.prisma.io/)**: A modern database toolkit that provides a type-safe and efficient way to interact with databases.
-   **[UploadThing](https://uploadthing.com/)**: A file upload service that provides a secure and efficient way to upload files to the cloud.

## What is EV0?

So, what is EV0? A template? A framework? A stack? The answer is all of the above. It's a template because it provides a starting point for your project. It's a framework because it provides a set of tools and conventions for building web applications. And it's a stack because it combines multiple technologies to create a cohesive development experience.

## Why EV0?

There are many reasons to use the EV0 Stack, but here are a few of the most compelling:

1. **Type Safety**: EV0 is built on top of TypeScript, which provides static types for JavaScript. This means you can catch errors at compile time rather than at runtime, leading to more robust and maintainable code.

2. **Performance**: EV0 uses Next.js, which enables server-side rendering and static site generation. This means your web applications will load faster and perform better, leading to a better user experience.

3. **Developer Experience**: EV0 provides a set of tools and conventions that make it easy to build web applications. This includes a collection of accessible, reusable, and customizable UI components, a type-safe API framework, and a real-time database and authentication system.

4. **Scalability**: EV0 is designed to scale with your project. Whether you're building a small prototype or a large production application, EV0 provides the tools and infrastructure you need to succeed.

5. **Community**: EV0 has a vibrant and active community of developers who are passionate about building web applications. Whether you have a question, need help, or want to contribute, the EV0 community is here to support you.

This will prompt you to choose a project name, select the features you want to include (e.g., authentication, database, etc.), and configure the project settings. Once you've answered all the questions, the command will generate a new project in the current directory with the specified settings.

> To quickly setup a new project with the default settings, you can run `npx create-ev0-app@latest -d`.

## Community

If you have any questions, need help, or want to contribute, you can join the EV0 community on Discord. We're here to support you and help you succeed with the EV0 Stack.

[![Discord](https://img.shields.io/discord/1133372614165934160?color=%235865F2&label=Discord&logo=discord&logoColor=%23fff)](https://dsc.gg/drvgo)

## Contributors

Thanks goes to these wonderful people.

<a href="https://github.com/itsdrvgo/create-ev0-app/graphs/contributors">
  <p align="center">
  <img src="https://contrib.rocks/image?repo=itsdrvgo/create-ev0-app" />
  </p>
</a>

<p align="center">
  Made with <a rel="noopener noreferrer" target="_blank" href="https://contrib.rocks">contrib.rocks</a>
</p>

<p align="center">
  <a rel="noopener noreferrer" target="_blank" href="https://vercel.com/?utm_source=itsdrvo&utm_campaign=oss">
    <img height="34px" src="https://www.datocms-assets.com/31049/1618983297-powered-by-vercel.svg" alt="Powered by vercel">
  </a>
</p>

==> create-ev0-app-0.3.1.tgz: package/README.md <==
# EV0 App

The best way to start your next Next.js project in a type-safe environment. Get started with the EV0 Stack by running `npx create-ev0-app@latest init`

## Getting Started

To get started with the EV0 Stack, you can run the following command:

```bash
npx create-ev0-app@latest init
# or
yarn create-ev0-app@latest init
# or
pnpm dlx create-ev0-app@latest init
# or
bunx create-ev0-app@latest init
```

## The EV0 Stack

The EV0 Stack is a full-stack TypeScript framework that helps you build fast, robust, and maintainable web applications using the latest technologies. It is built on top of the following technologies:

-   **[Next.js](https://nextjs.org/)**: A React framework that enables server-side rendering and static site generation.
-   **[TypeScript](https://www.typescriptlang.org/)**: A superset of JavaScript that adds static types to the language.
-   **[Tailwind CSS](https://tailwindcss.com/)**: A utility-first CSS framework for rapidly building custom designs.
-   **[ShadCN UI](https://ui.shadcn.com/)**: A collection of accessible, reusable, and customizable UI components.
-   **[tRPC](https://trpc.io/)**: A TypeScript-first framework for building scalable and type-safe APIs.
-   **[Supabase](https://supabase.io/)**: An open-source alternative to Firebase that provides a real-time database and authentication system.
-   **[Clerk](https://clerk.com/)**: A user authentication and authorization service that provides a secure and customizable login experience.
-   **[MongoDB](https://www.mongodb.com/)**: A NoSQL database that provides a flexible and scalable data storage solution.
-   **[Drizzle](https://orm.drizzle.team/)**: A TypeScript-first ORM that provides a type-safe and efficient way to interact with databases.
-   **[Prisma](https://www.prisma.io/)**: A modern database toolkit that provides a type-safe and efficient way to interact with databases.
-   **[UploadThing](https://uploadthing.com/)**: A file upload service that provides a secure and efficient way to upload files to the cloud.

## What is EV0?

So, what is EV0? A template? A framework? A stack? The answer is all of the above. It's a template because it provides a starting point for your project. It's a framework because it provides a set of tools and conventions for building web applications. And it's a stack because it combines multiple technologies to create a cohesive development experience.

## Why EV0?

There are many reasons to use the EV0 Stack, but here are a few of the most compelling:

1. **Type Safety**: EV0 is built on top of TypeScript, which provides static types for JavaScript. This means you can catch errors at compile time rather than at runtime, leading to more robust and maintainable code.

2. **Performance**: EV0 uses Next.js, which enables server-side rendering and static site generation. This means your web applications will load faster and perform better, leading to a better user experience.

3. **Developer Experience**: EV0 provides a set of tools and conventions that make it easy to build web applications. This includes a collection of accessible, reusable, and customizable UI components, a type-safe API framework, and a real-time database and authentication system.

4. **Scalability**: EV0 is designed to scale with your project. Whether you're building a small prototype or a large production application, EV0 provides the tools and infrastructure you need to succeed.

5. **Community**: EV0 has a vibrant and active community of developers who are passionate about building web applications. Whether you have a question, need help, or want to contribute, the EV0 community is here to support you.

This will prompt you to choose a project name, select the features you want to include (e.g., authentication, database, etc.), and configure the project settings. Once you've answered all the questions, the command will generate a new project in the current directory with the specified settings.

> To quickly setup a new project with the default settings, you can run `npx create-ev0-app@latest -d`.

## Community

If you have any questions, need help, or want to contribute, you can join the EV0 community on Discord. We're here to support you and help you succeed with the EV0 Stack.

[![Discord](https://img.shields.io/discord/1133372614165934160?color=%235865F2&label=Discord&logo=discord&logoColor=%23fff)](https://dsc.gg/drvgo)

## Contributors

Thanks goes to these wonderful people.

<a href="https://github.com/itsdrvgo/create-ev0-app/graphs/contributors">
  <p align="center">
  <img src="https://contrib.rocks/image?repo=itsdrvgo/create-ev0-app" />
  </p>
</a>

<p align="center">
  Made with <a rel="noopener noreferrer" target="_blank" href="https://contrib.rocks">contrib.rocks</a>
</p>

<p align="center">
  <a rel="noopener noreferrer" target="_blank" href="https://vercel.com/?utm_source=itsdrvo&utm_campaign=oss">
    <img height="34px" src="https://www.datocms-assets.com/31049/1618983297-powered-by-vercel.svg" alt="Powered by vercel">
  </a>
</p>
